---
feature_story: FS_58_61_77_69
feature_title: convenient `dev_shell`
feature_status: TEST
---

See also FS_85_33_46_53 `bootstrap_env`.

# Idea

This feature supports quick non-intrusive shell session with configured `argrelay`:
*   quick: single command `@/exe/dev_shell.bash` should do all the necessary steps to set up environment temporarily
*   non-intrusive: user environment is not affected (e.g. no changes to `~/.bashrc`) - only current shell session

See demo from the main [`readme.md`][root_readme.md] how it is used.

# Config

The script is normally immutable (symlink-ed to installed Python package).

In order to automate adding some extra shell settings use mutable `@/conf/dev_shell_env.bash`.

[root_readme.md]: ../../readme.md
